@@ -6,18 +6,17 @@ from decimal import Decimal
 from sql import Null
 
 from trytond.pool import PoolMeta, Pool
-from trytond.model import ModelSQL, ModelView, MatchMixin, Workflow, fields, \
-    sequence_ordered
+from trytond.model import (
+    ModelSQL, ModelView, MatchMixin, Workflow, DeactivableMixin, fields,
+    sequence_ordered)
 from trytond.pyson import Eval, If
 from trytond.transaction import Transaction
-from trytond import backend
 
 __all__ = ['Sale', 'SaleLine',
     'SaleExtra', 'SaleExtraLine']
 
 
-class Sale:
-    __metaclass__ = PoolMeta
+class Sale(metaclass=PoolMeta):
     __name__ = 'sale.sale'
 
     @classmethod
@@ -58,14 +57,13 @@ class Sale:
         self.lines = lines
 
 
-class SaleLine:
-    __metaclass__ = PoolMeta
+class SaleLine(metaclass=PoolMeta):
     __name__ = 'sale.line'
 
     extra = fields.Many2One('sale.extra.line', 'Extra', ondelete='RESTRICT')
 
 
-class SaleExtra(ModelSQL, ModelView, MatchMixin):
+class SaleExtra(DeactivableMixin, ModelSQL, ModelView, MatchMixin):
     'Sale Extra'
     __name__ = 'sale.extra'
 
@@ -79,7 +77,6 @@ class SaleExtra(ModelSQL, ModelView, MatchMixin):
                 Eval('context', {}).get('company', -1)),
             ],
         select=True)
-    active = fields.Boolean('Active')
     start_date = fields.Date('Start Date',
         domain=['OR',
             ('start_date', '<=', If(~Eval('end_date', None),
@@ -113,14 +110,13 @@ class SaleExtra(ModelSQL, ModelView, MatchMixin):
     def __register__(cls, module_name):
         pool = Pool()
         PriceList = pool.get('product.price_list')
-        TableHandler = backend.get('TableHandler')
         cursor = Transaction().connection.cursor()
         sql_table = cls.__table__()
         price_list = PriceList.__table__()
 
         super(SaleExtra, cls).__register__(module_name)
 
-        table = TableHandler(cls, module_name)
+        table = cls.__table_handler__(module_name)
         # Migration from 3.6: price_list not required and new company
         table.not_null_action('price_list', 'remove')
         query = sql_table.join(price_list,
@@ -137,10 +133,6 @@ class SaleExtra(ModelSQL, ModelView, MatchMixin):
     def default_company():
         return Transaction().context.get('company')
 
-    @staticmethod
-    def default_active():
-        return True
-
     @fields.depends('company')
     def on_change_with_currency_digits(self, name=None):
         if self.company:
